# Class: console

A console

## Fields for class: console

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`location`          |`string`            |_RO/runtime_   |URI for the console service             |
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`protocol`          |`console_protocol`  |_RO/runtime_   |the protocol used by this console       |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VM`                |`VM ref`            |_RO/runtime_   |VM to which this console is attached    |

## RPCs associated with class: console

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given console.

_Signature:_

```
void add_to_other_config (session ref session_ref, console ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`console ref`                 |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create a new console instance, and return its handle.

_Signature:_

```
console ref create (session ref session_ref, console record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`console record`              |`args`                        |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `console ref`

reference to the newly created object

### RPC name: destroy

_Overview:_

Destroy the specified console instance.

_Signature:_

```
void destroy (session ref session_ref, console ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`console ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the consoles known to the system.

_Signature:_

```
console ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `console ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of console references to console records for all consoles known to the system.

_Signature:_

```
(console ref -> console record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(console ref -> console record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the console instance with the specified UUID.

_Signature:_

```
console ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `console ref`

reference to the object

### RPC name: get&#95;location

_Overview:_

Get the location field of the given console.

_Signature:_

```
string get_location (session ref session_ref, console ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`console ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given console.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, console ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`console ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;protocol

_Overview:_

Get the protocol field of the given console.

_Signature:_

```
console_protocol get_protocol (session ref session_ref, console ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`console ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `console_protocol`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given console.

_Signature:_

```
console record get_record (session ref session_ref, console ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`console ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `console record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given console.

_Signature:_

```
string get_uuid (session ref session_ref, console ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`console ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VM

_Overview:_

Get the VM field of the given console.

_Signature:_

```
VM ref get_VM (session ref session_ref, console ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`console ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given console.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, console ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`console ref`                 |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given console.

_Signature:_

```
void set_other_config (session ref session_ref, console ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`console ref`                 |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`
