# Class: PIF&#95;metrics

The metrics associated with a physical network interface

## Fields for class: PIF&#95;metrics

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`carrier`           |`bool`              |_RO/runtime_   |Report if the PIF got a carrier or not  |
|`device_id`         |`string`            |_RO/runtime_   |Report device ID                        |
|`device_name`       |`string`            |_RO/runtime_   |Report device name                      |
|`duplex`            |`bool`              |_RO/runtime_   |Full duplex capability of the link &#40;if available&#41;|
|`io_read_kbs`       |`float`             |_RO/runtime_   |**Removed.** Read bandwidth &#40;KiB/s&#41;          |
|`io_write_kbs`      |`float`             |_RO/runtime_   |**Removed.** Write bandwidth &#40;KiB/s&#41;         |
|`last_updated`      |`datetime`          |_RO/runtime_   |Time at which this information was last updated|
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`pci_bus_path`      |`string`            |_RO/runtime_   |PCI bus path of the pif &#40;if available&#41;|
|`speed`             |`int`               |_RO/runtime_   |Speed of the link in Mbit/s &#40;if available&#41;|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`vendor_id`         |`string`            |_RO/runtime_   |Report vendor ID                        |
|`vendor_name`       |`string`            |_RO/runtime_   |Report vendor name                      |

## RPCs associated with class: PIF&#95;metrics

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given PIF&#95;metrics.

_Signature:_

```
void add_to_other_config (session ref session_ref, PIF_metrics ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the PIF&#95;metrics instances known to the system.

_Signature:_

```
PIF_metrics ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `PIF_metrics ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PIF&#95;metrics references to PIF&#95;metrics records for all PIF&#95;metrics instances known to the system.

_Signature:_

```
(PIF_metrics ref -> PIF_metrics record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(PIF_metrics ref -> PIF_metrics record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PIF&#95;metrics instance with the specified UUID.

_Signature:_

```
PIF_metrics ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PIF_metrics ref`

reference to the object

### RPC name: get&#95;carrier

_Overview:_

Get the carrier field of the given PIF&#95;metrics.

_Signature:_

```
bool get_carrier (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;device&#95;id

_Overview:_

Get the device&#95;id field of the given PIF&#95;metrics.

_Signature:_

```
string get_device_id (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;device&#95;name

_Overview:_

Get the device&#95;name field of the given PIF&#95;metrics.

_Signature:_

```
string get_device_name (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;duplex

_Overview:_

Get the duplex field of the given PIF&#95;metrics.

_Signature:_

```
bool get_duplex (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;io&#95;read&#95;kbs

**This message is removed.**

_Overview:_

Get the io/read&#95;kbs field of the given PIF&#95;metrics.

_Signature:_

```
float get_io_read_kbs (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

### RPC name: get&#95;io&#95;write&#95;kbs

**This message is removed.**

_Overview:_

Get the io/write&#95;kbs field of the given PIF&#95;metrics.

_Signature:_

```
float get_io_write_kbs (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

### RPC name: get&#95;last&#95;updated

_Overview:_

Get the last&#95;updated field of the given PIF&#95;metrics.

_Signature:_

```
datetime get_last_updated (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given PIF&#95;metrics.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;pci&#95;bus&#95;path

_Overview:_

Get the pci&#95;bus&#95;path field of the given PIF&#95;metrics.

_Signature:_

```
string get_pci_bus_path (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PIF&#95;metrics.

_Signature:_

```
PIF_metrics record get_record (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF_metrics record`

all fields from the object

### RPC name: get&#95;speed

_Overview:_

Get the speed field of the given PIF&#95;metrics.

_Signature:_

```
int get_speed (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PIF&#95;metrics.

_Signature:_

```
string get_uuid (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;vendor&#95;id

_Overview:_

Get the vendor&#95;id field of the given PIF&#95;metrics.

_Signature:_

```
string get_vendor_id (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;vendor&#95;name

_Overview:_

Get the vendor&#95;name field of the given PIF&#95;metrics.

_Signature:_

```
string get_vendor_name (session ref session_ref, PIF_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given PIF&#95;metrics.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, PIF_metrics ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given PIF&#95;metrics.

_Signature:_

```
void set_other_config (session ref session_ref, PIF_metrics ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF_metrics ref`             |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
