# Class: tunnel

A tunnel for network traffic

## Fields for class: tunnel

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`access_PIF`        |`PIF ref`           |_RO/constructor_|The interface through which the tunnel is accessed|
|`other_config`      |`(string -> string) map`|_RW_           |Additional configuration                |
|`protocol`          |`tunnel_protocol`   |_RW_           |The protocol used for tunneling &#40;either GRE or VxLAN&#41;|
|`status`            |`(string -> string) map`|_RW_           |Status information about the tunnel     |
|`transport_PIF`     |`PIF ref`           |_RO/constructor_|The interface used by the tunnel        |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: tunnel

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given tunnel.

_Signature:_

```
void add_to_other_config (session ref session_ref, tunnel ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;status

_Overview:_

Add the given key&#45;value pair to the status field of the given tunnel.

_Signature:_

```
void add_to_status (session ref session_ref, tunnel ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create a tunnel

_Signature:_

```
tunnel ref create (session ref session_ref, PIF ref transport_PIF, network ref network, tunnel_protocol protocol)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`transport_PIF`               |PIF which receives the tagged traffic   |
|`network ref`                 |`network`                     |Network to receive the tunnelled traffic|
|`tunnel_protocol`             |`protocol`                    |Protocol used for the tunnel &#40;GRE or VxLAN&#41;|

_Minimum Role:_ pool-operator

_Return Type:_ `tunnel ref`

The reference of the created tunnel object

_Possible Error Codes:_ `OPENVSWITCH_NOT_ACTIVE`, `TRANSPORT_PIF_NOT_CONFIGURED`, `IS_TUNNEL_ACCESS_PIF`

### RPC name: destroy

_Overview:_

Destroy a tunnel

_Signature:_

```
void destroy (session ref session_ref, tunnel ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |tunnel to destroy                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;access&#95;PIF

_Overview:_

Get the access&#95;PIF field of the given tunnel.

_Signature:_

```
PIF ref get_access_PIF (session ref session_ref, tunnel ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

### RPC name: get&#95;all

_Overview:_

Return a list of all the tunnels known to the system.

_Signature:_

```
tunnel ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `tunnel ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of tunnel references to tunnel records for all tunnels known to the system.

_Signature:_

```
(tunnel ref -> tunnel record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(tunnel ref -> tunnel record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the tunnel instance with the specified UUID.

_Signature:_

```
tunnel ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `tunnel ref`

reference to the object

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given tunnel.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, tunnel ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;protocol

_Overview:_

Get the protocol field of the given tunnel.

_Signature:_

```
tunnel_protocol get_protocol (session ref session_ref, tunnel ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `tunnel_protocol`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given tunnel.

_Signature:_

```
tunnel record get_record (session ref session_ref, tunnel ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `tunnel record`

all fields from the object

### RPC name: get&#95;status

_Overview:_

Get the status field of the given tunnel.

_Signature:_

```
(string -> string) map get_status (session ref session_ref, tunnel ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;transport&#95;PIF

_Overview:_

Get the transport&#95;PIF field of the given tunnel.

_Signature:_

```
PIF ref get_transport_PIF (session ref session_ref, tunnel ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given tunnel.

_Signature:_

```
string get_uuid (session ref session_ref, tunnel ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given tunnel.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, tunnel ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;status

_Overview:_

Remove the given key and its corresponding value from the status field of the given tunnel.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_status (session ref session_ref, tunnel ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given tunnel.

_Signature:_

```
void set_other_config (session ref session_ref, tunnel ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;protocol

_Overview:_

Set the protocol field of the given tunnel.

_Signature:_

```
void set_protocol (session ref session_ref, tunnel ref self, tunnel_protocol value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |
|`tunnel_protocol`             |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;status

_Overview:_

Set the status field of the given tunnel.

_Signature:_

```
void set_status (session ref session_ref, tunnel ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`tunnel ref`                  |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
