# Class: VIF

A virtual network interface

## Fields for class: VIF

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allowed_operations`|`vif_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`current_operations`|`(string -> vif_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`currently_attached`|`bool`              |_RO/constructor_|is the device currently attached &#40;erased on reboot&#41;|
|`device`            |`string`            |_RO/constructor_|order in which VIF backends are created by xapi|
|`ipv4_addresses`    |`string set`        |_RO/runtime_   |IPv4 addresses in CIDR format           |
|`ipv4_allowed`      |`string set`        |_RO/constructor_|A list of IPv4 addresses which can be used to filter traffic passing through this VIF|
|`ipv4_configuration_mode`|`vif_ipv4_configuration_mode`|_RO/runtime_   |Determines whether IPv4 addresses are configured on the VIF|
|`ipv4_gateway`      |`string`            |_RO/runtime_   |IPv4 gateway &#40;the empty string means that no gateway is set&#41;|
|`ipv6_addresses`    |`string set`        |_RO/runtime_   |IPv6 addresses in CIDR format           |
|`ipv6_allowed`      |`string set`        |_RO/constructor_|A list of IPv6 addresses which can be used to filter traffic passing through this VIF|
|`ipv6_configuration_mode`|`vif_ipv6_configuration_mode`|_RO/runtime_   |Determines whether IPv6 addresses are configured on the VIF|
|`ipv6_gateway`      |`string`            |_RO/runtime_   |IPv6 gateway &#40;the empty string means that no gateway is set&#41;|
|`locking_mode`      |`vif_locking_mode`  |_RO/constructor_|current locking mode of the VIF         |
|`MAC`               |`string`            |_RO/constructor_|ethernet MAC address of virtual interface, as exposed to guest|
|`MAC_autogenerated` |`bool`              |_RO/runtime_   |true if the MAC was autogenerated; false indicates it was set manually|
|`metrics`           |`VIF_metrics ref`   |_RO/runtime_   |**Removed.** metrics associated with this VIF        |
|`MTU`               |`int`               |_RO/constructor_|MTU in octets                           |
|`network`           |`network ref`       |_RO/constructor_|virtual network to which this vif is connected|
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`qos_algorithm_params`|`(string -> string) map`|_RW_           |parameters for chosen QoS algorithm     |
|`qos_algorithm_type`|`string`            |_RW_           |QoS algorithm to use                    |
|`qos_supported_algorithms`|`string set`        |_RO/runtime_   |supported QoS algorithms for this VIF   |
|`runtime_properties`|`(string -> string) map`|_RO/runtime_   |Device runtime properties               |
|`status_code`       |`int`               |_RO/runtime_   |error/success code associated with last attach&#45;operation &#40;erased on reboot&#41;|
|`status_detail`     |`string`            |_RO/runtime_   |error/success information associated with last attach&#45;operation status &#40;erased on reboot&#41;|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VM`                |`VM ref`            |_RO/constructor_|virtual machine to which this vif is connected|

## RPCs associated with class: VIF

### RPC name: add&#95;ipv4&#95;allowed

_Overview:_

Associates an IPv4 address with this VIF

_Signature:_

```
void add_ipv4_allowed (session ref session_ref, VIF ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF which the IP address will be associated with|
|`string`                      |`value`                       |The IP address which will be associated with the VIF|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: add&#95;ipv6&#95;allowed

_Overview:_

Associates an IPv6 address with this VIF

_Signature:_

```
void add_ipv6_allowed (session ref session_ref, VIF ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF which the IP address will be associated with|
|`string`                      |`value`                       |The IP address which will be associated with the VIF|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VIF.

_Signature:_

```
void add_to_other_config (session ref session_ref, VIF ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: add&#95;to&#95;qos&#95;algorithm&#95;params

_Overview:_

Add the given key&#45;value pair to the qos/algorithm&#95;params field of the given VIF.

_Signature:_

```
void add_to_qos_algorithm_params (session ref session_ref, VIF ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: configure&#95;ipv4

_Overview:_

Configure IPv4 settings for this virtual interface

_Signature:_

```
void configure_ipv4 (session ref session_ref, VIF ref self, vif_ipv4_configuration_mode mode, string address, string gateway)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF to configure                    |
|`vif_ipv4_configuration_mode` |`mode`                        |Whether to use static or no IPv4 assignment|
|`string`                      |`address`                     |The IPv4 address in &lt;addr&gt;/&lt;prefix length&gt; format &#40;for static mode only&#41;|
|`string`                      |`gateway`                     |The IPv4 gateway &#40;for static mode only; leave empty to not set a gateway&#41;|

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: configure&#95;ipv6

_Overview:_

Configure IPv6 settings for this virtual interface

_Signature:_

```
void configure_ipv6 (session ref session_ref, VIF ref self, vif_ipv6_configuration_mode mode, string address, string gateway)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF to configure                    |
|`vif_ipv6_configuration_mode` |`mode`                        |Whether to use static or no IPv6 assignment|
|`string`                      |`address`                     |The IPv6 address in &lt;addr&gt;/&lt;prefix length&gt; format &#40;for static mode only&#41;|
|`string`                      |`gateway`                     |The IPv6 gateway &#40;for static mode only; leave empty to not set a gateway&#41;|

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create a new VIF instance, and return its handle.

_Signature:_

```
VIF ref create (session ref session_ref, VIF record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF record`                  |`args`                        |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `VIF ref`

reference to the newly created object

### RPC name: destroy

_Overview:_

Destroy the specified VIF instance.

_Signature:_

```
void destroy (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the VIFs known to the system.

_Signature:_

```
VIF ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VIF ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VIF references to VIF records for all VIFs known to the system.

_Signature:_

```
(VIF ref -> VIF record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VIF ref -> VIF record) map`

records of all objects

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given VIF.

_Signature:_

```
vif_operations set get_allowed_operations (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vif_operations set`

value of the field

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VIF instance with the specified UUID.

_Signature:_

```
VIF ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VIF ref`

reference to the object

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given VIF.

_Signature:_

```
(string -> vif_operations) map get_current_operations (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> vif_operations) map`

value of the field

### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given VIF.

_Signature:_

```
bool get_currently_attached (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;device

_Overview:_

Get the device field of the given VIF.

_Signature:_

```
string get_device (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;ipv4&#95;addresses

_Overview:_

Get the ipv4&#95;addresses field of the given VIF.

_Signature:_

```
string set get_ipv4_addresses (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;ipv4&#95;allowed

_Overview:_

Get the ipv4&#95;allowed field of the given VIF.

_Signature:_

```
string set get_ipv4_allowed (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;ipv4&#95;configuration&#95;mode

_Overview:_

Get the ipv4&#95;configuration&#95;mode field of the given VIF.

_Signature:_

```
vif_ipv4_configuration_mode get_ipv4_configuration_mode (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vif_ipv4_configuration_mode`

value of the field

### RPC name: get&#95;ipv4&#95;gateway

_Overview:_

Get the ipv4&#95;gateway field of the given VIF.

_Signature:_

```
string get_ipv4_gateway (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;ipv6&#95;addresses

_Overview:_

Get the ipv6&#95;addresses field of the given VIF.

_Signature:_

```
string set get_ipv6_addresses (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;ipv6&#95;allowed

_Overview:_

Get the ipv6&#95;allowed field of the given VIF.

_Signature:_

```
string set get_ipv6_allowed (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;ipv6&#95;configuration&#95;mode

_Overview:_

Get the ipv6&#95;configuration&#95;mode field of the given VIF.

_Signature:_

```
vif_ipv6_configuration_mode get_ipv6_configuration_mode (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vif_ipv6_configuration_mode`

value of the field

### RPC name: get&#95;ipv6&#95;gateway

_Overview:_

Get the ipv6&#95;gateway field of the given VIF.

_Signature:_

```
string get_ipv6_gateway (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;locking&#95;mode

_Overview:_

Get the locking&#95;mode field of the given VIF.

_Signature:_

```
vif_locking_mode get_locking_mode (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vif_locking_mode`

value of the field

### RPC name: get&#95;MAC

_Overview:_

Get the MAC field of the given VIF.

_Signature:_

```
string get_MAC (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;MAC&#95;autogenerated

_Overview:_

Get the MAC&#95;autogenerated field of the given VIF.

_Signature:_

```
bool get_MAC_autogenerated (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;metrics

**This message is removed.**

_Overview:_

Get the metrics field of the given VIF.

_Signature:_

```
VIF_metrics ref get_metrics (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VIF_metrics ref`

value of the field

### RPC name: get&#95;MTU

_Overview:_

Get the MTU field of the given VIF.

_Signature:_

```
int get_MTU (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;network

_Overview:_

Get the network field of the given VIF.

_Signature:_

```
network ref get_network (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network ref`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VIF.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;qos&#95;algorithm&#95;params

_Overview:_

Get the qos/algorithm&#95;params field of the given VIF.

_Signature:_

```
(string -> string) map get_qos_algorithm_params (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;qos&#95;algorithm&#95;type

_Overview:_

Get the qos/algorithm&#95;type field of the given VIF.

_Signature:_

```
string get_qos_algorithm_type (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;qos&#95;supported&#95;algorithms

_Overview:_

Get the qos/supported&#95;algorithms field of the given VIF.

_Signature:_

```
string set get_qos_supported_algorithms (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VIF.

_Signature:_

```
VIF record get_record (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VIF record`

all fields from the object

### RPC name: get&#95;runtime&#95;properties

_Overview:_

Get the runtime&#95;properties field of the given VIF.

_Signature:_

```
(string -> string) map get_runtime_properties (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;status&#95;code

_Overview:_

Get the status&#95;code field of the given VIF.

_Signature:_

```
int get_status_code (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;status&#95;detail

_Overview:_

Get the status&#95;detail field of the given VIF.

_Signature:_

```
string get_status_detail (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VIF.

_Signature:_

```
string get_uuid (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VM

_Overview:_

Get the VM field of the given VIF.

_Signature:_

```
VM ref get_VM (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

### RPC name: move

_Overview:_

Move the specified VIF to the specified network, even while the VM is running

_Signature:_

```
void move (session ref session_ref, VIF ref self, network ref network)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF to move                         |
|`network ref`                 |`network`                     |The network to move it to               |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: plug

_Overview:_

Hotplug the specified VIF, dynamically attaching it to the running VM

_Signature:_

```
void plug (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF to hotplug                      |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VIF.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, VIF ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;qos&#95;algorithm&#95;params

_Overview:_

Remove the given key and its corresponding value from the qos/algorithm&#95;params field of the given VIF.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_qos_algorithm_params (session ref session_ref, VIF ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: remove&#95;ipv4&#95;allowed

_Overview:_

Removes an IPv4 address from this VIF

_Signature:_

```
void remove_ipv4_allowed (session ref session_ref, VIF ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF from which the IP address will be removed|
|`string`                      |`value`                       |The IP address which will be removed from the VIF|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;ipv6&#95;allowed

_Overview:_

Removes an IPv6 address from this VIF

_Signature:_

```
void remove_ipv6_allowed (session ref session_ref, VIF ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF from which the IP address will be removed|
|`string`                      |`value`                       |The IP address which will be removed from the VIF|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;ipv4&#95;allowed

_Overview:_

Set the IPv4 addresses to which traffic on this VIF can be restricted

_Signature:_

```
void set_ipv4_allowed (session ref session_ref, VIF ref self, string set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF which the IP addresses will be associated with|
|`string set`                  |`value`                       |The IP addresses which will be associated with the VIF|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;ipv6&#95;allowed

_Overview:_

Set the IPv6 addresses to which traffic on this VIF can be restricted

_Signature:_

```
void set_ipv6_allowed (session ref session_ref, VIF ref self, string set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF which the IP addresses will be associated with|
|`string set`                  |`value`                       |The IP addresses which will be associated with the VIF|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;locking&#95;mode

_Overview:_

Set the locking mode for this VIF

_Signature:_

```
void set_locking_mode (session ref session_ref, VIF ref self, vif_locking_mode value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF whose locking mode will be set  |
|`vif_locking_mode`            |`value`                       |The new locking mode for the VIF        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VIF.

_Signature:_

```
void set_other_config (session ref session_ref, VIF ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;qos&#95;algorithm&#95;params

_Overview:_

Set the qos/algorithm&#95;params field of the given VIF.

_Signature:_

```
void set_qos_algorithm_params (session ref session_ref, VIF ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;qos&#95;algorithm&#95;type

_Overview:_

Set the qos/algorithm&#95;type field of the given VIF.

_Signature:_

```
void set_qos_algorithm_type (session ref session_ref, VIF ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: unplug

_Overview:_

Hot&#45;unplug the specified VIF, dynamically unattaching it from the running VM

_Signature:_

```
void unplug (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF to hot&#45;unplug               |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: unplug&#95;force

_Overview:_

Forcibly unplug the specified VIF

_Signature:_

```
void unplug_force (session ref session_ref, VIF ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VIF ref`                     |`self`                        |The VIF to forcibly unplug              |

_Minimum Role:_ vm-admin

_Return Type:_ `void`
